"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPlugins = void 0;
var shared_1 = require("@dev-scripts/shared");
var CopyPlugin = require("copy-webpack-plugin");
var MiniCssExtractPlugin = require("mini-css-extract-plugin");
var SassLintPlugin = require("sass-lint-webpack");
var webpack_1 = require("webpack");
var ESLintPlugin = require('eslint-webpack-plugin');
var WebpackManifestPlugin = require('webpack-manifest-plugin').WebpackManifestPlugin;
var env = (0, shared_1.getEnv)();
var mode = (0, shared_1.getDefaultMode)();
var isDevelopment = mode === 'development';
var getPlugins = function (isClient, manifestSharedSeed) {
    if (isClient === void 0) { isClient = true; }
    if (manifestSharedSeed === void 0) { manifestSharedSeed = {}; }
    return [
        isClient && new SassLintPlugin(),
        isClient && shared_1.devConfig.copy && new CopyPlugin(shared_1.devConfig.copy),
        isClient &&
            new ESLintPlugin({
                emitWarning: true,
                failOnError: true,
            }),
        isClient &&
            !isDevelopment &&
            new MiniCssExtractPlugin({
                filename: (0, shared_1.normalizePath)("".concat(shared_1.devConfig.cssOutputPath).concat(isDevelopment || !shared_1.devConfig.contenthash
                    ? '[name].css'
                    : '[name].[contenthash].css')),
                chunkFilename: (0, shared_1.normalizePath)("".concat(shared_1.devConfig.cssOutputPath).concat(isDevelopment || !shared_1.devConfig.contenthash
                    ? '[id].css'
                    : '[id].[contenthash].css')),
            }),
        isClient &&
            new WebpackManifestPlugin({
                fileName: 'asset-manifest.json',
                seed: manifestSharedSeed,
                writeToFileEmit: true,
            }),
        new webpack_1.DefinePlugin(env.stringified),
        new webpack_1.DefinePlugin({
            __SERVER__: !isClient,
            __BROWSER__: isClient,
        }),
    ].filter(Boolean);
};
exports.getPlugins = getPlugins;
//# sourceMappingURL=plugins.js.map